==> YNQ-1.5.1_Linux_S_CP.zip: YNQ-1.5.1_Linux_S_CP/NQ Library Reference/html/search/all_64.js <==
var searchData=
[
  ['dns_20and_20wins',['DNS and WINS',['../group__cm__dns.html',1,'']]],
  ['data',['data',['../structNQ__IOVecBuffer.html#aa89afe53012afdf83b5b389016ab8e6c',1,'NQ_IOVecBuffer::data()'],['../structCMIOVecBlob.html#a5b2c82d78517840ee7da9d768f622eea',1,'CMIOVecBlob::data()']]],
  ['datafile',['dataFile',['../structSYPrinterDriver.html#ab3bdcdfc20046eafbb81d054a9e6a4d0',1,'SYPrinterDriver']]],
  ['datatype',['dataType',['../structSYPrinterInfo.html#acd3f1acc09a23a27d3b0750d29c18193',1,'SYPrinterInfo']]],
  ['day',['day',['../structSYTimeFragments.html#ac28facb32c70251a66287a8f8164d0f8',1,'SYTimeFragments']]],
  ['defaultdatatype',['defaultDataType',['../structSYPrinterDriver.html#a0b98acd103a7913c75cb105e55469d05',1,'SYPrinterDriver']]],
  ['defaultpriority',['defaultPriority',['../structSYPrinterInfo.html#ab48e48710a51ba27c1c5ded84cb89fda',1,'SYPrinterInfo']]],
  ['defaultsource',['defaultSource',['../structSYDeviceMode.html#a7c8df98bfd4009898a70814ecea6eeb9',1,'SYDeviceMode']]],
  ['dependentfiles',['dependentFiles',['../structSYPrinterDriver.html#ac8b29383e668ad7ac53d0306220a544f',1,'SYPrinterDriver']]],
  ['devicenotselectedtimeout',['deviceNotSelectedTimeout',['../structSYPrinterInfo.html#acacfaa3156fc4bdb4e07ba57ee4deaef',1,'SYPrinterInfo']]],
  ['devmode',['devMode',['../structSYPrinterInfo.html#a9e24545b82b72cdb28be12c2908329e4',1,'SYPrinterInfo']]],
  ['dialect',['dialect',['../structCCServerInfo.html#a0c6ea5c14c29944549e8dd222ee6412f',1,'CCServerInfo']]],
  ['dialects_20operations',['Dialects Operations',['../group__dialects.html',1,'']]],
  ['direct_20transfer',['Direct Transfer',['../group__direct.html',1,'']]],
  ['directories',['Directories',['../group__directories.html',1,'']]],
  ['directory_20operations',['Directory Operations',['../group__directory.html',1,'']]],
  ['displayflags',['displayFlags',['../structSYDeviceMode.html#a8bcc366c44c95b7364e0c4017722f25d',1,'SYDeviceMode']]],
  ['displayfrequency',['displayFrequency',['../structSYDeviceMode.html#aacaace9ae9bc398cf22ba07417afba6f',1,'SYDeviceMode']]],
  ['dithertype',['ditherType',['../structSYDeviceMode.html#a68f5cd7298ac1e35c892612ade423982',1,'SYDeviceMode']]],
  ['documentname',['documentName',['../structSYPrintJobInfo.html#ad43407ab5916f56488ebcdb206f418c6',1,'SYPrintJobInfo']]],
  ['domain',['domain',['../structAMCredentialsA.html#a0513425a6c69fd1471bd16e933abfd5e',1,'AMCredentialsA::domain()'],['../structAMCredentials.html#acc2ee1f3d9a31f36e030107f15ae2e54',1,'AMCredentials::domain()'],['../group__domain.html',1,'(Global Namespace)']]],
  ['domain_5flength',['DOMAIN_LENGTH',['../group__credential.html#ga152c511778cefa3a8c5c1d5357a2251c',1,'ccapi.h']]],
  ['dos_5ferralreadyexists',['DOS_ERRalreadyexists',['../group__SMB__errors.html#ga999b411969ae98032adac5a9eeac4e19',1,'udapi.h']]],
  ['dos_5ferrbadaccess',['DOS_ERRbadaccess',['../group__SMB__errors.html#gadea98d8a8e104b13e4248db0b67c546e',1,'udapi.h']]],
  ['dos_5ferrbaddata',['DOS_ERRbaddata',['../group__SMB__errors.html#ga4b8929b8cb6ef76ea66721923cecc35e',1,'udapi.h']]],
  ['dos_5ferrbaddirectory',['DOS_ERRbaddirectory',['../group__SMB__errors.html#ga64b0eb39242cb07ac61b087e45fddedd',1,'udapi.h']]],
  ['dos_5ferrbaddrive',['DOS_ERRbaddrive',['../group__SMB__errors.html#gabf50d00c9331938ca720f4703e7ff3c1',1,'udapi.h']]],
  ['dos_5ferrbadenv',['DOS_ERRbadenv',['../group__SMB__errors.html#ga562708a6df1db4675fb32b41b7aa2cd7',1,'udapi.h']]],
  ['dos_5ferrbadfid',['DOS_ERRbadfid',['../group__SMB__errors.html#gaaaf28ab0f493185734fc67a485fc1efc',1,'udapi.h']]],
  ['dos_5ferrbadfile',['DOS_ERRbadfile',['../group__SMB__errors.html#gabc34deec01aa3c6b64545ea8d9df352a',1,'udapi.h']]],
  ['dos_5ferrbadformat',['DOS_ERRbadformat',['../group__SMB__errors.html#gab999fe028b1ed15a9a30931e35288380',1,'udapi.h']]],
  ['dos_5ferrbadfunc',['DOS_ERRbadfunc',['../group__SMB__errors.html#ga43e0c6a47dd12090784755fe8ab685ce',1,'udapi.h']]],
  ['dos_5ferrbadmcb',['DOS_ERRbadmcb',['../group__SMB__errors.html#gaf9c0274a89777c62a7507060efc891bd',1,'udapi.h']]],
  ['dos_5ferrbadmem',['DOS_ERRbadmem',['../group__SMB__errors.html#gad59556ce311283bc102acd9035467722',1,'udapi.h']]],
  ['dos_5ferrbadpath',['DOS_ERRbadpath',['../group__SMB__errors.html#ga6ee7fee839184d08172dd7bac6588027',1,'udapi.h']]],
  ['dos_5ferrbadpipe',['DOS_ERRbadpipe',['../group__SMB__errors.html#ga5d5ec2cdcf7ff3f2161c8ad52628679d',1,'udapi.h']]],
  ['dos_5ferrbadshare',['DOS_ERRbadshare',['../group__SMB__errors.html#gaff336eda5f04056592a5a4630480bf9f',1,'udapi.h']]],
  ['dos_5ferrdiffdevice',['DOS_ERRdiffdevice',['../group__SMB__errors.html#gac87627bcaa9032042ff9609e2598857b',1,'udapi.h']]],
  ['dos_5ferrdirnotempty',['DOS_ERRdirnotempty',['../group__SMB__errors.html#ga00fb71b438ae9cd23b9ecb71116b4044',1,'udapi.h']]],
  ['dos_5ferrdontsupportipc',['DOS_ERRdontsupportipc',['../group__SMB__errors.html#ga3c50d81d4b460baad22d9b5cf4ac3b6f',1,'udapi.h']]],
  ['dos_5ferrfileexists',['DOS_ERRfileexists',['../group__SMB__errors.html#ga71f1b5319470dc2735c52f796d4464d3',1,'udapi.h']]],
  ['dos_5ferrinsufficientbuffer',['DOS_ERRinsufficientbuffer',['../group__SMB__errors.html#gadc3d56d8a48ce50fd16edd95ced9df54',1,'udapi.h']]],
  ['dos_5ferrinvalidname',['DOS_ERRinvalidname',['../group__SMB__errors.html#gafe18392573d33dba5faf8f92d30d1f03',1,'udapi.h']]],
  ['dos_5ferrlock',['DOS_ERRlock',['../group__SMB__errors.html#ga15ddf56743196ffa7248aee43ac31046',1,'udapi.h']]],
  ['dos_5ferrmoredata',['DOS_ERRmoredata',['../group__SMB__errors.html#ga4b296eafa7742eacf75d85d308e6941a',1,'udapi.h']]],
  ['dos_5ferrnoaccess',['DOS_ERRnoaccess',['../group__SMB__errors.html#ga5cc593d261cfc874ce596e3aa330c76f',1,'udapi.h']]],
  ['dos_5ferrnofids',['DOS_ERRnofids',['../group__SMB__errors.html#ga441783343fc909a9f8f712d189b82134',1,'udapi.h']]],
  ['dos_5ferrnofiles',['DOS_ERRnofiles',['../group__SMB__errors.html#gabf33ca1303a62fc4db87ed9cab44c3b6',1,'udapi.h']]],
  ['dos_5ferrnomem',['DOS_ERRnomem',['../group__SMB__errors.html#ga1316cb7a6e95975c87857e7b7505184c',1,'udapi.h']]],
  ['dos_5ferrnoshare',['DOS_ERRnoshare',['../group__SMB__errors.html#ga4367d646e4d90f987577db4ce004179f',1,'udapi.h']]],
  ['dos_5ferrnotconnected',['DOS_ERRnotconnected',['../group__SMB__errors.html#ga139d713094d05dfb25021ffe546ce9be',1,'udapi.h']]],
  ['dos_5ferrpipebusy',['DOS_ERRpipebusy',['../group__SMB__errors.html#gaa1d3eecd806128f73b12fd05ac913750',1,'udapi.h']]],
  ['dos_5ferrpipeclosing',['DOS_ERRpipeclosing',['../group__SMB__errors.html#gab2466d7226551a253fe2d59984da48f5',1,'udapi.h']]],
  ['dos_5ferrremcd',['DOS_ERRremcd',['../group__SMB__errors.html#ga0234e6b43275a1b07920406703adf1a4',1,'udapi.h']]],
  ['driverdate',['driverDate',['../structSYPrinterDriver.html#ae96e88ed32f24421c93effe7fe16892d',1,'SYPrinterDriver']]],
  ['driverextradata',['driverExtraData',['../structSYDeviceMode.html#af58c58230230ab0c08e809cd791844e1',1,'SYDeviceMode']]],
  ['driverextralength',['driverExtraLength',['../structSYDeviceMode.html#acbb67638516f22b87fc22ea0aaf7769d',1,'SYDeviceMode']]],
  ['drivername',['driverName',['../structSYPrinterInfo.html#ae310f15ef2104b3b047e7afea12bc3f7',1,'SYPrinterInfo']]],
  ['driverpath',['driverPath',['../structSYPrinterDriver.html#ae95ebc3e6117a7011ccc4670b35c3250',1,'SYPrinterDriver']]],
  ['driverversion',['driverVersion',['../structSYDeviceMode.html#aa4ec29e5cc438b14223ea7a476fe410f',1,'SYDeviceMode::driverVersion()'],['../structSYPrinterDriver.html#a446d0d7250b2652f9306a65e68532808',1,'SYPrinterDriver::driverVersion()']]],
  ['driverversions',['driverVersions',['../structSYPrinterDriver.html#aaa5c0c1f0c11e3be0fcbf7585303f6fd',1,'SYPrinterDriver']]],
  ['duplex',['duplex',['../structSYDeviceMode.html#af665d76d6acf0101190b9dec66127113',1,'SYDeviceMode']]],
  ['driver_20notification_20events',['Driver Notification Events',['../group__notification.html',1,'']]]
];

==> YNQ-1.6.2_Linux_S_CP.zip: YNQ-1.6.2_Linux_S_CP/NQ Library Reference/html/search/all_64.js <==
var searchData=
[
  ['data_20structures',['Data Structures',['../group__cm__datastruct.html',1,'']]],
  ['dns_20and_20wins',['DNS and WINS',['../group__cm__dns.html',1,'']]],
  ['data',['data',['../structNQ__IOVecBuffer.html#aa89afe53012afdf83b5b389016ab8e6c',1,'NQ_IOVecBuffer::data()'],['../structCMIOVecBlob.html#a5b2c82d78517840ee7da9d768f622eea',1,'CMIOVecBlob::data()']]],
  ['datafile',['dataFile',['../structSYPrinterDriver.html#ab3bdcdfc20046eafbb81d054a9e6a4d0',1,'SYPrinterDriver']]],
  ['datatype',['dataType',['../structSYPrinterInfo.html#acd3f1acc09a23a27d3b0750d29c18193',1,'SYPrinterInfo']]],
  ['day',['day',['../structSYTimeFragments.html#ac28facb32c70251a66287a8f8164d0f8',1,'SYTimeFragments']]],
  ['defaultdatatype',['defaultDataType',['../structSYPrinterDriver.html#a0b98acd103a7913c75cb105e55469d05',1,'SYPrinterDriver']]],
  ['defaultpriority',['defaultPriority',['../structSYPrinterInfo.html#ab48e48710a51ba27c1c5ded84cb89fda',1,'SYPrinterInfo']]],
  ['defaultsource',['defaultSource',['../structSYDeviceMode.html#a7c8df98bfd4009898a70814ecea6eeb9',1,'SYDeviceMode']]],
  ['dependentfiles',['dependentFiles',['../structSYPrinterDriver.html#ac8b29383e668ad7ac53d0306220a544f',1,'SYPrinterDriver']]],
  ['devicenotselectedtimeout',['deviceNotSelectedTimeout',['../structSYPrinterInfo.html#acacfaa3156fc4bdb4e07ba57ee4deaef',1,'SYPrinterInfo']]],
  ['devmode',['devMode',['../structSYPrinterInfo.html#a9e24545b82b72cdb28be12c2908329e4',1,'SYPrinterInfo']]],
  ['dialect',['dialect',['../structCCServerInfo.html#a0c6ea5c14c29944549e8dd222ee6412f',1,'CCServerInfo']]],
  ['dialects_20operations',['Dialects Operations',['../group__dialects.html',1,'']]],
  ['direct_20transfer',['Direct Transfer',['../group__direct.html',1,'']]],
  ['directories',['Directories',['../group__directories.html',1,'']]],
  ['directory_20operations',['Directory Operations',['../group__directory.html',1,'']]],
  ['displayflags',['displayFlags',['../structSYDeviceMode.html#a8bcc366c44c95b7364e0c4017722f25d',1,'SYDeviceMode']]],
  ['displayfrequency',['displayFrequency',['../structSYDeviceMode.html#aacaace9ae9bc398cf22ba07417afba6f',1,'SYDeviceMode']]],
  ['dithertype',['ditherType',['../structSYDeviceMode.html#a68f5cd7298ac1e35c892612ade423982',1,'SYDeviceMode']]],
  ['divider',['divider',['../structCMLinkedListArray.html#a46b4c2788d6dbb93c0b6c6940c4461c5',1,'CMLinkedListArray']]],
  ['documentname',['documentName',['../structSYPrintJobInfo.html#ad43407ab5916f56488ebcdb206f418c6',1,'SYPrintJobInfo']]],
  ['domain',['domain',['../structAMCredentialsA.html#a0513425a6c69fd1471bd16e933abfd5e',1,'AMCredentialsA::domain()'],['../structAMCredentials.html#acc2ee1f3d9a31f36e030107f15ae2e54',1,'AMCredentials::domain()'],['../group__domain.html',1,'(Global Namespace)']]],
  ['domain_5flength',['DOMAIN_LENGTH',['../group__credential.html#ga152c511778cefa3a8c5c1d5357a2251c',1,'ccapi.h']]],
  ['dos_5ferralreadyexists',['DOS_ERRalreadyexists',['../group__SMB__errors.html#ga999b411969ae98032adac5a9eeac4e19',1,'udapi.h']]],
  ['dos_5ferrbadaccess',['DOS_ERRbadaccess',['../group__SMB__errors.html#gadea98d8a8e104b13e4248db0b67c546e',1,'udapi.h']]],
  ['dos_5ferrbaddata',['DOS_ERRbaddata',['../group__SMB__errors.html#ga4b8929b8cb6ef76ea66721923cecc35e',1,'udapi.h']]],
  ['dos_5ferrbaddirectory',['DOS_ERRbaddirectory',['../group__SMB__errors.html#ga64b0eb39242cb07ac61b087e45fddedd',1,'udapi.h']]],
  ['dos_5ferrbaddrive',['DOS_ERRbaddrive',['../group__SMB__errors.html#gabf50d00c9331938ca720f4703e7ff3c1',1,'udapi.h']]],
  ['dos_5ferrbadenv',['DOS_ERRbadenv',['../group__SMB__errors.html#ga562708a6df1db4675fb32b41b7aa2cd7',1,'udapi.h']]],
  ['dos_5ferrbadfid',['DOS_ERRbadfid',['../group__SMB__errors.html#gaaaf28ab0f493185734fc67a485fc1efc',1,'udapi.h']]],
  ['dos_5ferrbadfile',['DOS_ERRbadfile',['../group__SMB__errors.html#gabc34deec01aa3c6b64545ea8d9df352a',1,'udapi.h']]],
  ['dos_5ferrbadformat',['DOS_ERRbadformat',['../group__SMB__errors.html#gab999fe028b1ed15a9a30931e35288380',1,'udapi.h']]],
  ['dos_5ferrbadfunc',['DOS_ERRbadfunc',['../group__SMB__errors.html#ga43e0c6a47dd12090784755fe8ab685ce',1,'udapi.h']]],
  ['dos_5ferrbadmcb',['DOS_ERRbadmcb',['../group__SMB__errors.html#gaf9c0274a89777c62a7507060efc891bd',1,'udapi.h']]],
  ['dos_5ferrbadmem',['DOS_ERRbadmem',['../group__SMB__errors.html#gad59556ce311283bc102acd9035467722',1,'udapi.h']]],
  ['dos_5ferrbadpath',['DOS_ERRbadpath',['../group__SMB__errors.html#ga6ee7fee839184d08172dd7bac6588027',1,'udapi.h']]],
  ['dos_5ferrbadpipe',['DOS_ERRbadpipe',['../group__SMB__errors.html#ga5d5ec2cdcf7ff3f2161c8ad52628679d',1,'udapi.h']]],
  ['dos_5ferrbadshare',['DOS_ERRbadshare',['../group__SMB__errors.html#gaff336eda5f04056592a5a4630480bf9f',1,'udapi.h']]],
  ['dos_5ferrdiffdevice',['DOS_ERRdiffdevice',['../group__SMB__errors.html#gac87627bcaa9032042ff9609e2598857b',1,'udapi.h']]],
  ['dos_5ferrdirnotempty',['DOS_ERRdirnotempty',['../group__SMB__errors.html#ga00fb71b438ae9cd23b9ecb71116b4044',1,'udapi.h']]],
  ['dos_5ferrdontsupportipc',['DOS_ERRdontsupportipc',['../group__SMB__errors.html#ga3c50d81d4b460baad22d9b5cf4ac3b6f',1,'udapi.h']]],
  ['dos_5ferrfileexists',['DOS_ERRfileexists',['../group__SMB__errors.html#ga71f1b5319470dc2735c52f796d4464d3',1,'udapi.h']]],
  ['dos_5ferrinsufficientbuffer',['DOS_ERRinsufficientbuffer',['../group__SMB__errors.html#gadc3d56d8a48ce50fd16edd95ced9df54',1,'udapi.h']]],
  ['dos_5ferrinvalidname',['DOS_ERRinvalidname',['../group__SMB__errors.html#gafe18392573d33dba5faf8f92d30d1f03',1,'udapi.h']]],
  ['dos_5ferrlock',['DOS_ERRlock',['../group__SMB__errors.html#ga15ddf56743196ffa7248aee43ac31046',1,'udapi.h']]],
  ['dos_5ferrmoredata',['DOS_ERRmoredata',['../group__SMB__errors.html#ga4b296eafa7742eacf75d85d308e6941a',1,'udapi.h']]],
  ['dos_5ferrnoaccess',['DOS_ERRnoaccess',['../group__SMB__errors.html#ga5cc593d261cfc874ce596e3aa330c76f',1,'udapi.h']]],
  ['dos_5ferrnofids',['DOS_ERRnofids',['../group__SMB__errors.html#ga441783343fc909a9f8f712d189b82134',1,'udapi.h']]],
  ['dos_5ferrnofiles',['DOS_ERRnofiles',['../group__SMB__errors.html#gabf33ca1303a62fc4db87ed9cab44c3b6',1,'udapi.h']]],
  ['dos_5ferrnomem',['DOS_ERRnomem',['../group__SMB__errors.html#ga1316cb7a6e95975c87857e7b7505184c',1,'udapi.h']]],
  ['dos_5ferrnoshare',['DOS_ERRnoshare',['../group__SMB__errors.html#ga4367d646e4d90f987577db4ce004179f',1,'udapi.h']]],
  ['dos_5ferrnotconnected',['DOS_ERRnotconnected',['../group__SMB__errors.html#ga139d713094d05dfb25021ffe546ce9be',1,'udapi.h']]],
  ['dos_5ferrpipebusy',['DOS_ERRpipebusy',['../group__SMB__errors.html#gaa1d3eecd806128f73b12fd05ac913750',1,'udapi.h']]],
  ['dos_5ferrpipeclosing',['DOS_ERRpipeclosing',['../group__SMB__errors.html#gab2466d7226551a253fe2d59984da48f5',1,'udapi.h']]],
  ['dos_5ferrremcd',['DOS_ERRremcd',['../group__SMB__errors.html#ga0234e6b43275a1b07920406703adf1a4',1,'udapi.h']]],
  ['driverdate',['driverDate',['../structSYPrinterDriver.html#ae96e88ed32f24421c93effe7fe16892d',1,'SYPrinterDriver']]],
  ['driverextradata',['driverExtraData',['../structSYDeviceMode.html#af58c58230230ab0c08e809cd791844e1',1,'SYDeviceMode']]],
  ['driverextralength',['driverExtraLength',['../structSYDeviceMode.html#acbb67638516f22b87fc22ea0aaf7769d',1,'SYDeviceMode']]],
  ['drivername',['driverName',['../structSYPrinterInfo.html#ae310f15ef2104b3b047e7afea12bc3f7',1,'SYPrinterInfo']]],
  ['driverpath',['driverPath',['../structSYPrinterDriver.html#ae95ebc3e6117a7011ccc4670b35c3250',1,'SYPrinterDriver']]],
  ['driverversion',['driverVersion',['../structSYDeviceMode.html#aa4ec29e5cc438b14223ea7a476fe410f',1,'SYDeviceMode::driverVersion()'],['../structSYPrinterDriver.html#a446d0d7250b2652f9306a65e68532808',1,'SYPrinterDriver::driverVersion()']]],
  ['driverversions',['driverVersions',['../structSYPrinterDriver.html#aaa5c0c1f0c11e3be0fcbf7585303f6fd',1,'SYPrinterDriver']]],
  ['duplex',['duplex',['../structSYDeviceMode.html#af665d76d6acf0101190b9dec66127113',1,'SYDeviceMode']]],
  ['driver_20notification_20events',['Driver Notification Events',['../group__notification.html',1,'']]]
];
